@@ -4,7 +4,7 @@ import numpy as np
 import sys
 
 
-class RandomForest(object):
+class RandomForestRegressor(object):
 
     def __init__(self, n_trees, trees=[], max_depth=10, gamma=sys.float_info.max, min_split_sample=10):
         self.n_trees = n_trees
